@@ -158,7 +158,7 @@ our %EXPORT_TAGS = (
 
 our @EXPORT = qw();
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 require XSLoader;
 XSLoader::load('Ouroboros', $VERSION);
@@ -721,7 +721,7 @@ Perl macro: C<SvTRUE_nomg>
 
 =item ouroboros_sv_type_ptr
 
-    OUROBOROS_STATIC IV ouroboros_sv_type(pTHX_ SV*);
+    OUROBOROS_STATIC svtype ouroboros_sv_type(pTHX_ SV*);
 
 Perl macro: C<SvTYPE>
 
@@ -1118,107 +1118,35 @@ C<@Ouroboros::CONSTS> contains names of all constants provided by this package.
 
 =item C<SVt_LAST>
 
-=item C<SV_IMMEDIATE_UNREF>
-
-=item C<SV_GMAGIC>
-
-=item C<SV_COW_DROP_PV>
-
-=item C<SV_UTF8_NO_ENCODING>
-
-=item C<SV_NOSTEAL>
-
-=item C<SV_CONST_RETURN>
-
-=item C<SV_MUTABLE_RETURN>
-
-=item C<SV_SMAGIC>
-
-=item C<SV_HAS_TRAILING_NUL>
-
-=item C<SV_COW_SHARED_HASH_KEYS>
-
-=item C<SV_COW_OTHER_PVS>
-
-=item C<SV_UNDEF_RETURNS_NULL>
-
-=item C<SV_FORCE_UTF8_UPGRADE>
-
-=item C<SV_SKIP_OVERLOAD>
-
 =item C<SV_CATBYTES>
 
 =item C<SV_CATUTF8>
 
-=item C<SV_CONST_TIESCALAR>
+=item C<SV_COW_DROP_PV>
 
-=item C<SV_CONST_TIEARRAY>
+=item C<SV_COW_OTHER_PVS>
 
-=item C<SV_CONST_TIEHASH>
+=item C<SV_COW_SHARED_HASH_KEYS>
 
-=item C<SV_CONST_TIEHANDLE>
+=item C<SV_FORCE_UTF8_UPGRADE>
 
-=item C<SV_CONST_FETCH>
+=item C<SV_GMAGIC>
 
-=item C<SV_CONST_FETCHSIZE>
+=item C<SV_HAS_TRAILING_NUL>
 
-=item C<SV_CONST_STORE>
+=item C<SV_IMMEDIATE_UNREF>
 
-=item C<SV_CONST_STORESIZE>
+=item C<SV_MUTABLE_RETURN>
 
-=item C<SV_CONST_EXISTS>
+=item C<SV_NOSTEAL>
 
-=item C<SV_CONST_PUSH>
+=item C<SV_SKIP_OVERLOAD>
 
-=item C<SV_CONST_POP>
+=item C<SV_SMAGIC>
 
-=item C<SV_CONST_SHIFT>
+=item C<SV_UNDEF_RETURNS_NULL>
 
-=item C<SV_CONST_UNSHIFT>
-
-=item C<SV_CONST_SPLICE>
-
-=item C<SV_CONST_EXTEND>
-
-=item C<SV_CONST_FIRSTKEY>
-
-=item C<SV_CONST_NEXTKEY>
-
-=item C<SV_CONST_SCALAR>
-
-=item C<SV_CONST_OPEN>
-
-=item C<SV_CONST_WRITE>
-
-=item C<SV_CONST_PRINT>
-
-=item C<SV_CONST_PRINTF>
-
-=item C<SV_CONST_READ>
-
-=item C<SV_CONST_READLINE>
-
-=item C<SV_CONST_GETC>
-
-=item C<SV_CONST_SEEK>
-
-=item C<SV_CONST_TELL>
-
-=item C<SV_CONST_EOF>
-
-=item C<SV_CONST_BINMODE>
-
-=item C<SV_CONST_FILENO>
-
-=item C<SV_CONST_CLOSE>
-
-=item C<SV_CONST_DELETE>
-
-=item C<SV_CONST_CLEAR>
-
-=item C<SV_CONST_UNTIE>
-
-=item C<SV_CONST_DESTROY>
+=item C<SV_UTF8_NO_ENCODING>
 
 
 
