@@ -2,213 +2,167 @@ package Ouroboros::Spec;
 use strict;
 use warnings;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 # spec {
 our %SPEC = (
   "const" => [
     {
-      "name" => "SV_IMMEDIATE_UNREF"
+      "c_type" => "U32",
+      "name" => "SV_CATBYTES",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_GMAGIC"
+      "c_type" => "U32",
+      "name" => "SV_CATUTF8",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_COW_DROP_PV"
+      "c_type" => "U32",
+      "name" => "SV_COW_DROP_PV",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_UTF8_NO_ENCODING"
+      "c_type" => "U32",
+      "name" => "SV_COW_OTHER_PVS",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_NOSTEAL"
+      "c_type" => "U32",
+      "name" => "SV_COW_SHARED_HASH_KEYS",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_CONST_RETURN"
+      "c_type" => "U32",
+      "name" => "SV_FORCE_UTF8_UPGRADE",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_MUTABLE_RETURN"
+      "c_type" => "U32",
+      "name" => "SV_GMAGIC",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_SMAGIC"
+      "c_type" => "U32",
+      "name" => "SV_HAS_TRAILING_NUL",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_HAS_TRAILING_NUL"
+      "c_type" => "U32",
+      "name" => "SV_IMMEDIATE_UNREF",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_COW_SHARED_HASH_KEYS"
+      "c_type" => "U32",
+      "name" => "SV_MUTABLE_RETURN",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_COW_OTHER_PVS"
+      "c_type" => "U32",
+      "name" => "SV_NOSTEAL",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_UNDEF_RETURNS_NULL"
+      "c_type" => "U32",
+      "name" => "SV_SKIP_OVERLOAD",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_FORCE_UTF8_UPGRADE"
+      "c_type" => "U32",
+      "name" => "SV_SMAGIC",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_SKIP_OVERLOAD"
+      "c_type" => "U32",
+      "name" => "SV_UNDEF_RETURNS_NULL",
+      "perl_type" => "UV"
     },
     {
-      "name" => "SV_CATBYTES"
-    },
-    {
-      "name" => "SV_CATUTF8"
-    },
-    {
-      "name" => "SV_CONST_TIESCALAR"
-    },
-    {
-      "name" => "SV_CONST_TIEARRAY"
-    },
-    {
-      "name" => "SV_CONST_TIEHASH"
-    },
-    {
-      "name" => "SV_CONST_TIEHANDLE"
-    },
-    {
-      "name" => "SV_CONST_FETCH"
-    },
-    {
-      "name" => "SV_CONST_FETCHSIZE"
-    },
-    {
-      "name" => "SV_CONST_STORE"
-    },
-    {
-      "name" => "SV_CONST_STORESIZE"
-    },
-    {
-      "name" => "SV_CONST_EXISTS"
-    },
-    {
-      "name" => "SV_CONST_PUSH"
-    },
-    {
-      "name" => "SV_CONST_POP"
-    },
-    {
-      "name" => "SV_CONST_SHIFT"
-    },
-    {
-      "name" => "SV_CONST_UNSHIFT"
-    },
-    {
-      "name" => "SV_CONST_SPLICE"
-    },
-    {
-      "name" => "SV_CONST_EXTEND"
-    },
-    {
-      "name" => "SV_CONST_FIRSTKEY"
-    },
-    {
-      "name" => "SV_CONST_NEXTKEY"
-    },
-    {
-      "name" => "SV_CONST_SCALAR"
-    },
-    {
-      "name" => "SV_CONST_OPEN"
-    },
-    {
-      "name" => "SV_CONST_WRITE"
-    },
-    {
-      "name" => "SV_CONST_PRINT"
-    },
-    {
-      "name" => "SV_CONST_PRINTF"
-    },
-    {
-      "name" => "SV_CONST_READ"
-    },
-    {
-      "name" => "SV_CONST_READLINE"
-    },
-    {
-      "name" => "SV_CONST_GETC"
-    },
-    {
-      "name" => "SV_CONST_SEEK"
-    },
-    {
-      "name" => "SV_CONST_TELL"
-    },
-    {
-      "name" => "SV_CONST_EOF"
-    },
-    {
-      "name" => "SV_CONST_BINMODE"
-    },
-    {
-      "name" => "SV_CONST_FILENO"
-    },
-    {
-      "name" => "SV_CONST_CLOSE"
-    },
-    {
-      "name" => "SV_CONST_DELETE"
-    },
-    {
-      "name" => "SV_CONST_CLEAR"
-    },
-    {
-      "name" => "SV_CONST_UNTIE"
-    },
-    {
-      "name" => "SV_CONST_DESTROY"
+      "c_type" => "U32",
+      "name" => "SV_UTF8_NO_ENCODING",
+      "perl_type" => "UV"
     }
   ],
   "enum" => [
     {
-      "name" => "SVt_NULL"
+      "c_type" => "svtype",
+      "name" => "SVt_NULL",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_IV"
+      "c_type" => "svtype",
+      "name" => "SVt_IV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_NV"
+      "c_type" => "svtype",
+      "name" => "SVt_NV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PV"
+      "c_type" => "svtype",
+      "name" => "SVt_PV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVIV"
+      "c_type" => "svtype",
+      "name" => "SVt_PVIV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVNV"
+      "c_type" => "svtype",
+      "name" => "SVt_PVNV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVMG"
+      "c_type" => "svtype",
+      "name" => "SVt_PVMG",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_REGEXP"
+      "c_type" => "svtype",
+      "name" => "SVt_REGEXP",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVGV"
+      "c_type" => "svtype",
+      "name" => "SVt_PVGV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVLV"
+      "c_type" => "svtype",
+      "name" => "SVt_PVLV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVAV"
+      "c_type" => "svtype",
+      "name" => "SVt_PVAV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVHV"
+      "c_type" => "svtype",
+      "name" => "SVt_PVHV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVCV"
+      "c_type" => "svtype",
+      "name" => "SVt_PVCV",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVFM"
+      "c_type" => "svtype",
+      "name" => "SVt_PVFM",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_PVIO"
+      "c_type" => "svtype",
+      "name" => "SVt_PVIO",
+      "perl_type" => "IV"
     },
     {
-      "name" => "SVt_LAST"
+      "c_type" => "svtype",
+      "name" => "SVt_LAST",
+      "perl_type" => "IV"
     }
   ],
   "fn" => [
@@ -1049,14 +1003,14 @@ our %SPEC = (
       "type" => "bool"
     },
     {
-      "c_decl" => "OUROBOROS_STATIC IV ouroboros_sv_type(pTHX_ SV*);",
+      "c_decl" => "OUROBOROS_STATIC svtype ouroboros_sv_type(pTHX_ SV*);",
       "name" => "ouroboros_sv_type",
       "params" => [
         "SV*"
       ],
       "ptr_name" => "ouroboros_sv_type_ptr",
       "tags" => {},
-      "type" => "IV"
+      "type" => "svtype"
     },
     {
       "c_decl" => "OUROBOROS_STATIC UV ouroboros_sv_flags(pTHX_ SV*);",
@@ -1675,6 +1629,14 @@ A list of supported numeric constants.
 
 Constant name.
 
+=item c_type
+
+Actual C type.
+
+=item perl_type
+
+Perl scalar variant used to export the constant value to Perl. One of: "IV" or "UV".
+
 =back
 
 =head2 Enum values
@@ -1692,6 +1654,14 @@ C<ExtUtils::Constant> implementation.
 
 Enum value name.
 
+=item c_type
+
+Actual C name of the enum.
+
+=item perl_type
+
+Perl scalar variant used to export the constant value to Perl. One of: "IV" or "UV".
+
 =back
 
 =head2 Functions
